@@ -12,4 +12,6 @@
 #  You should have received a copy of the GNU General Public License along with Firefly. If not, see
 #  <http://www.gnu.org/licenses/>.
 
+from .role import Role
+from .scope import Scope
 from .user import User
